/****************************************************************************
	Bagotronix
	1019 Crossing Brook Way
	Tallahassee, FL 32311

	(C) Copyright 1998 Bagotronix
	All rights reserved

	Filename:  		chktc.c
	Programmer(s):	Ivan Baggett
	Description:	Chickadee(tm) example application for thermocouples.
	comments:		Does not linearize thermocouple.  Use AD595 data sheet
					type K, Table I, p. 3.  A lookup table with interpolation
					is required to obtain accurate temperatures above 100 C.
****************************************************************************/

#include <dos.h>
#include <stdio.h>

#include "stdinc.h"
#include "chickade.h"
#include "csfcadc.h"
#include "csfc8255.h"

#define _getch getch		// for Borland console

IOPARMS pia = {	CHICKADEE_8255, 0 };

int main (void) {

	BOOLEAN done = FALSE;
	int c, i;
	UWORD u;
	UBYTE b;

	/*  initialize 8255: Port A = input, Port B = output, CL & CH = output */
	_8255_init (&pia, INPUT, OUTPUT, OUTPUT, OUTPUT);


	printf ("Strike the 'X' key to quit, any other alphanumeric key to sample.\n\n");

	while (!done) {
		while (!kbhit());
		c = _getch();
		if (c == 'x' || c == 'X')
			done = TRUE;

		printf ("\n");
		for (i = 0; i < 4; i++) {
			// 1mV/LSB for MAX186 using internal reference (4.095V)
			u = ADCget (MAX186, (UBYTE)i, 0);	/* MAX186, channel i, 0 acq delay */
			/* 12-bit ADC result is normalized to MSB, so denormalize it (/16) */
			u /= 16;
			// 5mV/C after resistor divider (2:1) on AD595 output (pots)
			u *= 2;
			// 10mV/C for AD595 and type K thermocouple
			u /= 10;

			// determine if thermocouple is connected
			// 0 -> disconnected, Port A[4..7] -> TC[0..3]
			if (!_8255_getbit (&pia, _8255_PORTA, (UBYTE)(i+4)))
				printf ("TC%d: NC\n", i);
			else
				printf ("TC%d: +%u C\n", i, u);	/* to remote console */
		}
	}

	return 0;
}
