/****************************************************************************
	Bagotronix
	1019 Crossing Brook Way
	Tallahassee, FL 32311

	(C) Copyright 1996 Bagotronix
	All rights reserved

	Filename:  		csfc8255.c
	Programmer(s):	Ivan Baggett
	Description:	Sunflower C(tm) library
					8255 Peripheral Interface Adapter functions
	comments:		all functions use only Mode 0 (basic input/output)
	revisions:		7/17/96
****************************************************************************/


#include <dos.h>
#include "stdinc.h"
#include "chickade.h"
#include "csfc8255.h"


static const UBYTE bitmask[] = {
	0x01, 0x02, 0x04, 0x08, 0x10, 0x20, 0x40, 0x80
};


/****************************************************************************
_8255_init():	initializes 8255 chips
	arguments:	ptr to IO parms, Port A config, Port B config, Port CL config,
				Port CH config
	returns:	nothing
	resources used:  the 8255
	comments:	config values:  0 = output, non-zero = input
		Port B must be configured as output for Chickadee U17
	verified:	7/18/96
****************************************************************************/
void _8255_init (IOPARMS *parms,
	BOOLEAN cfga, BOOLEAN cfgb, BOOLEAN cfgcl, BOOLEAN cfgch) {

	UBYTE c;

	c = 0x80 | (cfga ? 0x10 : 0) | (cfgb ? 0x02 : 0)
		| (cfgcl ? 0x01 : 0) | (cfgch ? 0x08 : 0);
	outportb (parms->base + 3, c);
}


/****************************************************************************
_8255_get():	reads a value from an 8255 port
	arguments:  ptr to IO parms, the port to read
	returns:	the port's value
	resources used:  the 8255
	comments:	0 = Port A, 1 = Port B, 2 = Port C
	verified:	7/18/96
****************************************************************************/
UBYTE _8255_get (IOPARMS *parms, UBYTE port) {

	return (inportb (parms->base + port));
}


/****************************************************************************
_8255_put():	writes a value to an 8255 port
	arguments:  ptr to IO parms, the port to write, the value to write
	returns:	the value to write
	resources used:  the 8255
	comments:	0 = Port A, 1 = Port B, 2 = Port C
	verified:	 7/18/96
****************************************************************************/
UBYTE _8255_put (IOPARMS *parms, UBYTE port, UBYTE value) {

	outportb (parms->base + port, value);
	return (value);
}


/****************************************************************************
_8255_getbit():	reads a bit from an 8255 port
	arguments:  ptr to IO parms, the port to write, the bit (0-7) to read
	returns:	the bit value read as BOOLEAN type
	resources used:  the 8255
	comments:	0 = Port A, 1 = Port B, 2 = Port C
	verified:	7/18/96
****************************************************************************/
BOOLEAN _8255_getbit (IOPARMS *parms, UBYTE port, UBYTE bit) {

	UBYTE c;

	c = inportb (parms->base + port);
	c &= bitmask[bit];
	return (c ? TRUE : FALSE);
}


/****************************************************************************
_8255_putbit():	writes a bit value to an 8255 port
	arguments:  ptr to IO parms, the port to write, the bit (0-7) to write,
		the bit value to write
	returns:	the bit value to write
	resources used:  the 8255
	comments:	0 = Port A, 1 = Port B, 2 = Port C
	verified:	7/18/96
****************************************************************************/
BOOLEAN _8255_putbit (IOPARMS *parms, UBYTE port, UBYTE bit, BOOLEAN value) {

	UBYTE c;
	UWORD d = parms->base + port;

	disable();
	c = inportb (d);
	if (value)
		c |= bitmask[bit];
	else
		c &= ~bitmask[bit];
	outportb (d, c);
	enable();
	return (value);
}
